@@ -72,7 +72,7 @@ class KafkaLogger(metaclass=SingletonMeta):
             connections_max_idle_ms=540000,  # 连接最大空闲时间
             reconnect_backoff_max_ms=10000,  # 增加重连退避最大时间
             max_in_flight_requests_per_connection=1,  # 限制单个连接上未确认的请求数量
-            enable_idempotence=True,  # 开启幂等性
+            # enable_idempotence=True,  # 开启幂等性
         )
 
         # 启动后台发送线程
@@ -490,7 +490,7 @@ class SYLogger:
             logger.info(_log)
 
         if os.getenv('DEV-LOG', 'false').lower() == 'true':
-            pprint(_log)
+            pprint.pprint(_log)
 
     @staticmethod
     def info(msg: any, *args, **kwargs):
